@@ -21,13 +21,12 @@
 #plot <- function(x, method = NULL, measure = "support", 
 #  shading = "lift", interactive = FALSE, data = NULL, control = NULL, ...) {
 
-# FIXME: also for itemsets 
 
 plotly_arules <- function(x, method = "scatterplot", 
   measure = c("support", "confidence"), shading = "lift", 
   max = 1000, ...) {
   
-  if(!is(x, "rules")) stop("x has to be a set of rules.")
+  if(!is(x, "associations")) stop("x has to be a set of rules.")
   
   methods <- c("scatterplot", "two-key plot", "matrix")
   
@@ -48,48 +47,84 @@ plotly_arules <- function(x, method = "scatterplot",
   measure <- qnames[pmatch(measure, qnames, duplicates.ok = TRUE)]
   shading <- qnames[pmatch(shading, qnames)]
   
-  if(methodNr == 1) .plotly_scatter(x, measure, shading, max = max, ...)
-  else .plotly_matrix(x, shading, max = max, ...)
+  if(methodNr == 1) 
+    .plotly_scatter(x, measure, shading, max = max, ...)
+  else 
+    .plotly_matrix(x, shading, max = max, ...)
+}
+
+## Interface used by plot
+scatterplot_plotly <- function(x,
+  measure = measure, shading = shading, control = control, ...) {
+  
+  control <- c(control, list(...))  
+  
+  control <- .get_parameters(control, list(
+    interactive = TRUE,
+    engine = "htmlwidget",
+    max = 1000,
+    colors = default_colors(2), 
+    jitter = NA, 
+    precision = 3,
+    marker = list()
+  ))
+  
+  quality(x)[["order"]] <- size(x) 
+  qnames <- names(quality(x))
+  measure <- qnames[pmatch(measure, qnames, duplicates.ok = TRUE)]
+  shading <- qnames[pmatch(shading, qnames)]
+ 
+  .plotly_scatter(x, measure, shading, control$colors, control$jitter, control$precision, control$max, control$marker)
 }
 
 .plotly_scatter <- function(x, 
   measure = c("support", "confidence"), shading = "lift", 
-  colors = default_colors(2), jitter = NA, precision = 3, max = 1000, ...) {
+  colors = default_colors(2), jitter = NA, precision = 3, 
+  max = 1000, marker = list(), ...) {
 
   colors <- rev(colors) 
  
   ### order (overplotting) and check for max 
-  o <- order(quality(x)[[shading]], decreasing = FALSE)
+  if(!is.na(shading)) o <- order(quality(x)[[shading]], decreasing = FALSE)
+  else o <- 1:length(x)
+  
   if(length(o) > max) {
-    warning("too many rules supplied only plotting the best ", 
-      max, " rules using ", shading, " (change parameter max if needed)")
+    warning("plot: Too many rules supplied. Only plotting the best ", 
+      max, " rules using measure ", shading, 
+      " (change parameter max if needed)", call. = FALSE)
     o <- tail(o, n = max)
   }
   
   x <- x[o]
-  q <- quality(x)[, c(measure, shading)]
-
+  if(!is.na(shading)) q <- quality(x)[, c(measure, shading)]
+  else q <- quality(x)[, measure]
+  
   for(i in 1:ncol(q)) {
     infin <- is.infinite(q[[i]])
     if(any(infin)) {
       replinfin <- signif(2 * max(q[[i]][!infin], na.rm = TRUE), 3)
-      warning(colnames(q)[i], " contains infinite values! Replaced by twice the max (", replinfin, ")!")
+      warning("plot: ", colnames(q)[i], " contains infinite values! Replaced by twice the max (", replinfin, ")!", call. = FALSE)
       q[[i]][infin] <- replinfin
     }
   } 
     
-  l <- labels(x, itemSep= ',<BR>&nbsp;&nbsp;', 
+  if(is(x, "rules")) l <- labels(x, itemSep= ',<BR>&nbsp;&nbsp;', 
     ruleSep = '<BR>&nbsp;&nbsp; => ', 
     setStart = '<B>{', setEnd = '}</B>')
+  else l <- labels(x, itemSep= ',<BR>&nbsp;&nbsp;', 
+    setStart = '<B>{', setEnd = '}</B>')
+  
   
   txt <- paste(paste0('[', o,']<BR>'), l, 
     paste('<BR><BR>', measure[1], ": ", signif(q[, measure[1]], precision), sep = ""),
     paste('<BR>', measure[2], ": ", signif(q[, measure[2]], precision), sep =""),
-    paste('<BR>', shading, ": ", 
-      if(is.numeric(q[, shading])) signif(q[, shading], precision) 
-      else q[, shading], sep="")
+    if(!is.na(shading)){ 
+      paste('<BR>', shading, ": ", 
+        if(is.numeric(q[, shading])) signif(q[, shading], precision) 
+        else q[, shading], sep="")
+      } else "" 
   )
- 
+  
   ### add x/y-jitter
   jitter <- jitter[1]
   if(is.na(jitter) && any(duplicated(q[,measure]))) {
@@ -99,18 +134,23 @@ plotly_arules <- function(x, method = "scatterplot",
   if(!is.na(jitter) && jitter>0) 
     for(m in measure) q[[m]] <- jitter(q[[m]], factor = jitter, amount = 0)
 
-  if(shading == "order")
+  if(is.na(shading)) 
+    p <- plot_ly(q, type = "scatter", x = q[,measure[1]], y = q[,measure[2]], 
+      hoverinfo = 'text', text = txt,
+      mode = 'markers', marker = marker 
+    ) 
+  else if(shading == "order")
     p <- plot_ly(q, type = "scatter", x = q[,measure[1]], y = q[,measure[2]], 
       hoverinfo = 'text', text = txt, 
       color = as.ordered(q[,shading]),
-      mode = 'markers', marker = list(...) 
+      mode = 'markers', marker = marker 
     ) 
   else
     p <- plot_ly(q, type = "scatter", x = q[,measure[1]], y = q[,measure[2]], 
       hoverinfo = 'text', text = txt, 
       color = q[,shading], colors = colors,
       mode = 'markers', 
-      marker = list(colorbar = list(title = shading), ...)
+      marker = c(list(colorbar = list(title = shading)), marker)
     ) 
   
   
@@ -120,6 +160,26 @@ plotly_arules <- function(x, method = "scatterplot",
   )
 }
 
+## interface for plot
+matrix_plotly <- function(x, measure, shading, control, ...) {
+  
+  control <- c(control, list(...))  
+  
+  control <- .get_parameters(control, list(
+    interactive = TRUE,
+    engine = "htmlwidget",
+    max = 1000,
+    colors = default_colors(2), 
+    reorder = TRUE,
+    precision = 3
+  ))
+  
+  qnames <- names(quality(x))
+  measure <- qnames[pmatch(measure, qnames, duplicates.ok = TRUE)]
+  
+  .plotly_matrix(x, measure[1], reorder = control$reorder, 
+    colors = control$colors, precision = control$precision, max = control$max) }
+
 .plotly_matrix <- function(x, measure = "lift", reorder = TRUE, 
   #colors = colorRamp(c("grey", "red"))) {
   colors = default_colors(2), precision = 3, max = 1000) {
@@ -127,8 +187,9 @@ plotly_arules <- function(x, method = "scatterplot",
   colors <- rev(colors)
   
   if(length(x) > max) {
-    warning("too many rules supplied only plotting the best ", 
-      max, " rules using ", measure, " (change parameter max if needed)")
+    warning("plot: Too many rules supplied. Only plotting the best ", 
+      max, " rules using ", measure, " (change parameter max if needed)", 
+      call. = FALSE)
     x <- tail(x, n = max, by = measure, decreasing = FALSE)
   }
   
@@ -136,8 +197,9 @@ plotly_arules <- function(x, method = "scatterplot",
     setStart = '<B>{', setEnd = '}</B>')
   
   if(reorder) {
-    o <- .reorder(m, method = "TSP")
-    m <- seriation::permute(m, o)
+    cm <- colMeans(m, na.rm = TRUE)
+    rm <- rowMeans(m, na.rm = TRUE)
+    m <- m[order(rm, decreasing = FALSE), order(cm, decreasing = TRUE)]
   }
 
   
@@ -153,8 +215,10 @@ plotly_arules <- function(x, method = "scatterplot",
     hoverinfo = 'text',
     text = txt
   ) %>% 
-    layout(xaxis=list(title="LHS",showticklabels = FALSE, showgrid = FALSE), 
-      yaxis=list(title="RHS", showticklabels = FALSE, showgrid = FALSE)
+    layout(xaxis=list(title="LHS", showticklabels = FALSE, 
+      showgrid = TRUE, ticks = ""), 
+      yaxis=list(title="RHS", showticklabels = FALSE, 
+        showgrid = TRUE, ticks = "")
       #,margin=list(l=200, autoexpand=TRUE)
       #yaxis=list(title="RHS", showticklabels = FALSE, showgrid = FALSE)
     )
